<?php
/**
 * Helper functions
 *
 * @package     RCP\AWeberPro\Functions
 * @since       1.0.0
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Get AWeber subscription lists
 *
 * @since       1.0.0
 * @return      mixed $lists array The list of available campaigns | string The returned error message
 */
function rcp_aweber_pro_get_lists() {
	if( ( $cached_lists = get_transient( 'rcp_aweber_pro_lists' ) ) === false ) {
		$secrets = get_option( 'rcp_aweber_pro_secrets' );

		if( $secrets ) {
			try {
				$return = rcp_aweber_pro()->api_helper->api->getAccount( $secrets['access_key'], $secrets['access_secret'] );

				if( is_object( $return ) ) {
					foreach( $return->lists as $list ) {
						$lists[$list->id] = $list->name;
					}

					set_transient( 'rcp_aweber_pro_lists', $lists, 60*60*24 );
				} else {
					$lists = __( 'Unable to get your AWeber lists.', 'rcp-aweber-pro' );
				}
			} catch( Exception $e ) {
				$lists = $e->getMessage();
			}
		} else {
			$lists = __( 'An unknown error occurred.', 'rcp-aweber-pro' );
		}
	} else {
		$lists = $cached_lists;
	}

	return $lists;
}


/**
 * Check if we should show the subscription field
 *
 * @since       1.0.0
 * @param       int $level A specific level to check
 * @return      bool $show True to show, false otherwise
 */
function rcp_aweber_pro_show_checkbox() {
	$settings = get_option( 'rcp_aweber_pro_settings' );
	$lists    = get_option( 'rcp_aweber_pro_subscription_lists' );
	$show     = false;

	if( ! empty( $settings['auth_code'] ) ) {
		if( ! empty( $settings['saved_list'] ) ) {
			$show = true;
		}

		if( is_array( $lists ) ) {
			$show = true;
		}
	}

	return $show;
}
