<?php
global $rcp_options;
$group_id = rcpga_group_accounts()->members->get_group_id();
$page     = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;
$per_page = 20;
$offset   = $per_page * ( absint( $page ) - 1 );
$search   = '';
if ( ! empty( $_GET['rcpga-search'] ) ) {
	$search = rawurldecode( $_GET['rcpga-search'] );
}
$args     = array(
	'number' => $per_page,
	'offset' => $offset
);

if ( ! empty( $search ) ) {
	if ( is_email( $search ) && ! username_exists( $search ) ) {
		$member = get_user_by( 'email', $search );
	} else {
		$member = get_user_by( 'login', $search );
	}

	if ( is_a( $member, 'WP_User' ) ) {
		$args['user_id'] = absint( $member->ID );
	}
}

$members = $member_list = rcpga_group_accounts()->members->get_members( $group_id, $args );

$current_page = add_query_arg( 'rcpga-group', absint( $group_id ), home_url( 'index.php' ) );

// this should never happen
if ( empty( $members ) ) {
	return;
}

$sort_order  = apply_filters( 'rcpga_member_role_sort_order', array( 'owner', 'admin', 'invited', 'member' ) );

// sort members by role
if ( ! empty( $sort_order ) ) {
	$member_list = array();

	foreach( $sort_order as $role ) {
		foreach( $members as $member ) {
			if ( $role == $member->role ) {
				$member_list[] = $member;
			}
		}
	}

}

if ( ! did_action( 'rcpga_dashboard_notifications' ) ) {
	do_action( 'rcpga_dashboard_notifications' );
}
?>

<h4 class="rcp-header"><?php _e( 'Group Members', 'rcp-group-accounts' ); ?></h4>

<form id="rcpga-members-search" method="GET" action="<?php echo esc_url( get_permalink() ); ?>">
	<label for="rcpga-members-search-input" class="screen-reader-text"><?php _e( 'Search Members', 'rcp-group-accounts' ); ?></label>
	<input type="search" id="rcpga-members-search-input" name="rcpga-search" placeholder="<?php esc_attr_e( 'Username or email', 'rcp-group-accounts' ); ?>" value="<?php echo esc_attr( $search ); ?>">
	<input type="submit" class="button" value="<?php esc_attr_e( 'Search members', 'rcp-group-accounts'); ?>">
</form>

<table class="rcp-table" id="rcpga-group-members-list">

	<thead>
	<tr>
		<th><?php _e( 'Name', 'rcp-group-accounts' ); ?></th>
		<th><?php _e( 'Role', 'rcp-group-accounts' ); ?></th>
		<th><?php _e( 'Actions', 'rcp-group-accounts' ); ?></th>
	</tr>
	</thead>

	<tbody>
	<?php if ( empty( $search ) || ( ! empty( $search ) && ! empty( $args['user_id'] ) ) ) : ?>
		<?php foreach ( $member_list as $member ) : ?>

			<?php
			if ( ! $user_data = get_userdata( $member->user_id ) ) {
				continue;
			}
			?>

			<tr>
				<?php do_action( 'rcpga_before_member_data', $user_data ); ?>
				<td class="member-name" data-th="<?php esc_attr_e( 'Name', 'rcp-group-accounts' ); ?>"><?php echo $user_data->display_name; ?></td>
				<td class="member-roll" data-th="<?php esc_attr_e( 'Role', 'rcp-group-accounts' ); ?>"><?php echo esc_html( rcpga_get_member_role_label( $member->role ) ); ?></td>
				<td class="member-actions" data-th="<?php esc_attr_e( 'Actions', 'rcp-group-accounts' ); ?>">
					<?php if ( 'owner' !== $member->role ) : ?>
						<a href="<?php echo esc_url( wp_nonce_url( add_query_arg( array( 'rcpga-action' => 'remove-member', 'rcpga-member' => absint( $member->user_id ) ), $current_page ), 'rcpga_remove_from_group' ) ); ?>"><?php _e( 'Remove from Group', 'rcp-group-accounts' ); ?></a><br />
						<?php if( 'admin' == $member->role ) : ?>
							<a href="<?php echo esc_url( wp_nonce_url( add_query_arg( array( 'rcpga-action' => 'make-member', 'rcpga-member' => absint( $member->user_id ) ), $current_page ), 'rcpga_make_member' ) ); ?>"><?php _e( 'Set as Member', 'rcp-group-accounts' ); ?></a>
						<?php elseif ( 'member' == $member->role ) : ?>
							<a href="<?php echo esc_url( wp_nonce_url( add_query_arg( array( 'rcpga-action' => 'make-admin', 'rcpga-member' => absint( $member->user_id ) ), $current_page ), 'rcpga_make_admin' ) ); ?>"><?php _e( 'Set as Admin', 'rcp-group-accounts' ); ?></a>
						<?php elseif ( 'invited' == $member->role ) : ?>
							<a href="<?php echo esc_url( wp_nonce_url( add_query_arg( array( 'rcpga-action' => 'make-member', 'rcpga-member' => absint( $member->user_id ) ), $current_page ), 'rcpga_make_member' ) ); ?>"><?php _e( 'Set as Member', 'rcp-group-accounts' ); ?></a> | 
							<a href="<?php echo esc_url( wp_nonce_url( add_query_arg( array( 'rcpga-action' => 'resend-invite', 'rcpga-member' => absint( $member->user_id ) ), $current_page ), 'rcpga_resend_invite' ) ); ?>"><?php _e( 'Resend Invite', 'rcp-group-accounts' ); ?></a>
						<?php endif; ?>
					<?php endif; ?>
				</td>
				<?php do_action( 'rcpga_after_member_data', $user_data ); ?>
			</tr>
		<?php endforeach; ?>
	<?php else : ?>
		<tr>
			<td colspan="3"><?php printf( __( 'Member &#8220;%s&#8221; not found. <a href="%s">Clear search.</a>', 'rcp-group-accounts' ), esc_html( $search ), esc_url( remove_query_arg( 'rcpga-search' ) ) ); ?></td>
		</tr>
	<?php endif; ?>
	</tbody>
</table>

<?php
// Pagination
if ( ! empty( $search ) ) {
	$total_members = rcpga_group_accounts()->members->count( $group_id, $args );
} else {
	$total_members = rcpga_group_accounts()->groups->get_member_count( $group_id );
}
$total_pages = ceil( $total_members / $per_page );

if ( $total_pages > 1 && ( empty( $search ) || ( ! empty( $search ) && ! empty( $args['user_id'] ) ) ) ) {
	?>
	<div id="rcpga-group-members-pagination">
		<?php
		$big = 999999;
		echo paginate_links( array(
			'base'     => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
			'format'   => '?paged=%#%',
			'total'    => $total_pages,
			'current'  => $page,
			'end_size' => 1,
			'mid_size' => 5,
		) );
		?>
	</div>
	<?php
}