<?php
namespace RCP\Addon\RestrictPastContent;

defined( 'WPINC' ) or die;

/**
 * Displays the form fields on the subscription level edit screen.
 */
function edit_subscription_form_fields( $level ) {

	global $rcp_levels_db;
	$restrict        = $rcp_levels_db->get_meta( $level->id, 'restrict_past_content', true );
	$offset          = $rcp_levels_db->get_meta( $level->id, 'restrict_past_content_offset', true );
	$offset          = ! empty( $offset ) ? $offset : 0;
	$offset_disabled = ! empty( $restrict ) ? false : true;

	echo form_script();
	echo form_style();
	?>

	<tr class="form-field" id="rcp-restrict-past-content-wrapper">
		<th scope="row" valign="top">
			<label for="rcp-restrict-past-content"><?php _e( 'Restrict Past Content', 'rcp-restrict-past-content' ); ?></label>
		</th>

		<td>
			<table class="rcp-restrict-past-content-controls-table">
				<thead>
					<tr class="rcp-restrict-past-content-controls-row">
						<th scope="col" class="rcp-restrict-past-content-enabled">
							<?php _e( 'Enabled', 'rcp-restrict-past-content' ); ?>
						</th>
						<th scope="col" class="rcp-restrict-past-content-offset">
							<?php _e( 'Exception Period', 'rcp-restrict-past-content' ); ?>
							<span alt="f223" class="rcp-help-tip dashicons dashicons-editor-help" title="<?php _e( 'If you want to allow members to view content published prior to their join date, enter the number of days prior to their join date content must be published within to be accessible. Enter 0 to allow only content published on or after the member\'s join date.', 'rcp-restrict-past-content' ); ?>">
						</th>
					</tr>
				</thead>
				<tbody>
					<td>
						<input type="checkbox" id="rcp-restrict-past-content" name="rcp-restrict-past-content" value="1" <?php checked( $restrict, true ); ?>>
					</td>
					<td>
						<input type="number" id="rcp-restrict-past-content-offset" name="rcp-restrict-past-content-offset" value="<?php echo esc_attr( $offset ); ?>" <?php if ( $offset_disabled ) { echo 'disabled="disabled"'; } ?>>
					</td>
					<input type="hidden" id="rcp-restrict-past-content-check" name="rcp-restrict-past-content-check" value="1">
				</tbody>
			</table>
			<p class="description"><?php _e( 'Enable this to restrict access to content published prior to the member\'s join date. Only content published on or after the member\'s join date will be visible to the member. If you want some content published prior to the join date to be accessible, define the number of days in the Exception Period field. For example, to give access to content published one week before registration, enter 7.', 'rcp-restrict-past-content' ); ?></p>
		</td>
	</tr>
<?php

}
add_action( 'rcp_edit_subscription_form', '\RCP\Addon\RestrictPastContent\edit_subscription_form_fields' );

/**
 * Displays the form fields on the subscription level add screen.
 */
function add_subscription_form_fields() {

	$offset_disabled = ! empty( $restrict ) ? false : true;
	echo form_script();
	echo form_style();

	?>
	<tr class="form-field" id="rcp-restrict-past-content-wrapper">
		<th scope="row" valign="top">
			<label for="rcp-restrict-past-content"><?php _e( 'Restrict Past Content', 'rcp-restrict-past-content' ); ?></label>
		</th>

		<td>
			<table class="rcp-restrict-past-content-controls-table">
				<thead>
					<tr class="rcp-restrict-past-content-controls-row">
						<th scope="col" class="rcp-restrict-past-content-enabled">
							<?php _e( 'Enabled', 'rcp-restrict-past-content' ); ?>
						</th>
						<th scope="col" class="rcp-restrict-past-content-offset">
							<?php _e( 'Exception Period', 'rcp-restrict-past-content' ); ?>
							<span alt="f223" class="rcp-help-tip dashicons dashicons-editor-help" title="<?php _e( 'If you want to allow members to view content published prior to their join date, enter the number of days prior to their join date content must be published within to be accessible. Enter 0 to allow only content published on or after the member\'s join date.', 'rcp-restrict-past-content' ); ?>">
						</th>
					</tr>
				</thead>
				<tbody>
					<td>
						<input type="checkbox" id="rcp-restrict-past-content" name="rcp-restrict-past-content" value="1">
					</td>
					<td>
						<input type="number" id="rcp-restrict-past-content-offset" name="rcp-restrict-past-content-offset" value="0" <?php if ( $offset_disabled ) { echo 'disabled="disabled"'; } ?>>
					</td>
					<input type="hidden" id="rcp-restrict-past-content-check" name="rcp-restrict-past-content-check" value="1">
				</tbody>
			</table>
			<p class="description"><?php _e( 'Enable this to restrict access to content published prior to the member\'s join date. Only content published on or after the member\'s join date will be visible to the member. If you want some content published prior to the join date to be accessible, define the number of days in the Exception Period field. For example, to give access to content published one week before registration, enter 7.', 'rcp-restrict-past-content' ); ?></p>
		</td>
	</tr>
<?php
}
add_action( 'rcp_add_subscription_form', '\RCP\Addon\RestrictPastContent\add_subscription_form_fields' );

/**
 * Saves the setting on the subscription edit screen.
 */
function save_subscription_form_fields( $id, $args ) {

	if ( isset( $_GET['activate_subscription'] ) || isset( $_GET['deactivate_subscription'] ) ) {
		return;
	}

	if ( ! isset( $_POST['rcp-restrict-past-content-check'] ) ) {
		return;
	}

	if ( ! current_user_can( 'rcp_manage_levels' ) ) {
		return;
	}

	global $rcp_levels_db;

	if ( ! isset( $_POST['rcp-restrict-past-content'] ) ) {
		$rcp_levels_db->delete_meta( $id, 'restrict_past_content', '1' );
		$rcp_levels_db->delete_meta( $id, 'restrict_past_content_offset' );
		return;
	}

	$rcp_levels_db->update_meta( $id, 'restrict_past_content', true );

	if ( ! empty( $_POST['rcp-restrict-past-content-offset'] ) ) {
		$rcp_levels_db->update_meta( $id, 'restrict_past_content_offset', absint( $_POST['rcp-restrict-past-content-offset'] ) );
	} else {
		$rcp_levels_db->delete_meta( $id, 'restrict_past_content_offset' );
	}
}
add_action( 'rcp_edit_subscription_level', '\RCP\Addon\RestrictPastContent\save_subscription_form_fields', 10, 2 );
add_action( 'rcp_add_subscription', '\RCP\Addon\RestrictPastContent\save_subscription_form_fields', 10, 2 );

/**
 * Outputs the form javascript.
 */
function form_script() {
	?>
	<script type="text/javascript">
		(function($) {
			$(document).ready( function() {
				$('#rcp-restrict-past-content').change( function() {
					if (this.checked) {
						$('#rcp-restrict-past-content-offset').prop('disabled', false);
					} else {
						$('#rcp-restrict-past-content-offset').prop('disabled', true);
					}
				})
			});
		})(jQuery);
	</script>
	<?php
}

/**
 * Outputs the form styles.
 */
function form_style() {
	?>
	<style type="text/css">
		.rcp-restrict-past-content-controls-table {
			width: 370px;
		}
		.rcp-restrict-past-content-controls-row th {
			padding-top: 3px;
			padding-bottom: 0;
		}
		.rcp-restrict-past-content-enabled {
			max-width: 40px;
		}
		.form-table th.rcp-restrict-past-content-offset {
			max-width: 100px;
		}
		#rcp-restrict-past-content-offset {
			width: 40px;
		}
	</style>
	<?php
}