<?php
/**
 * Add meta box fields
 *
 * @package     RCP\Restriction_Timeouts\Admin\Settings\MetaBox
 * @since       1.0.0
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}


/**
 * Add meta box fields
 *
 * @since       1.0.0
 * @return      void
 */
function rcp_restriction_timeouts_metabox_fields() {
	global $post;

	$timeout = get_post_meta( $post->ID, 'rcp_timeout', true );
	$timeout_was = get_post_meta( $post->ID, 'rcp_timeout_was', true );
	?>
	<tr>
		<th style="width: 20%" class="rcp_meta_box_label"><label for="rcp_timeout"><?php _e( 'Restriction Timeout', 'rcp-restriction-timeouts' ); ?></label></th>
		<td class="rcp_meta_box_field">
			<input type="text" name="rcp_timeout" id="rcp_timeout" value="<?php echo esc_attr( $timeout ); ?>" />
		</td>
		<td class="rcp_meta_box_desc"><?php printf( __( 'Choose when this %s should become unrestricted.', 'rcp-restriction-timeouts' ), get_post_type() ); ?></td>
	</tr>
	<?php if( $timeout_was ) : ?>
		<tr>
			<th style="width: 20%" class="rcp_meta_box_label"><label for="rcp_timeout"><?php _e( 'Restriction Timeout Was:', 'rcp-restriction-timeouts' ); ?></label></th>
			<td class="rcp_meta_box_field">
				<span><?php echo esc_html( $timeout_was ); ?></span>
			</td>
		</tr>
	<?php endif; ?>
	<?php
}
add_action( 'rcp_metabox_fields_after', 'rcp_restriction_timeouts_metabox_fields' );


/**
 * Save meta box fields
 *
 * @since       1.0.0
 * @param       int $post_id The ID of the post we are saving
 * @return      void
 */
function rcp_restriction_timeouts_save_meta_data( $post_id ) {
	// Check autosave
	if( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
	    return $post_id;
	}

	// Check permissions
	if( isset( $_POST['post_type'] ) && 'page' == $_POST['post_type'] ) {
		if( ! current_user_can( 'edit_page', $post_id ) ) {
			return $post_id;
		}
	} elseif( ! current_user_can( 'edit_post', $post_id ) ) {
		return $post_id;
	}

	$fields = array(
		'rcp_timeout'
	);

	foreach ( $fields as $field ) {
		if( isset( $_POST[$field] ) ) {
			$old  = get_post_meta( $post_id, $field, true );
			$data = sanitize_text_field( $_POST[$field] );

			if( ( $data || $data == 0 ) && $data != $old ) {
				update_post_meta( $post_id, $field, $data ) ;
			} elseif( '' == $data && $old ) {
				delete_post_meta( $post_id, $field, $old );
			}
		} else {
			delete_post_meta( $post_id, $field );
		}
	}
}
add_action( 'save_post', 'rcp_restriction_timeouts_save_meta_data' );
