<?php
/**
 * Plugin Name:     Restrict Content Pro - Timelock
 * Plugin URI:      https://restrictcontentpro.com/downloads/restriction-timelock/
 * Description:     Restrict content after a certain date with RCP
 * Version:         1.0.1
 * Author:          Restrict Content Pro Team
 * Text Domain:     rcp-timelock
 *
 * @package         RCP\Timelock
 * @author          Daniel J Griffiths <dgriffiths@section214.com>
 * @copyright       Copyright (c) 2016, Daniel J Griffiths
 */


// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) {
	exit;
}


if( ! class_exists( 'RCP_Timelock' ) ) {


	/**
	 * Main RCP_Timelock class
	 *
	 * @since       1.0.0
	 */
	class RCP_Timelock {


		/**
		 * @var         RCP_Timelock $instance The one true RCP_Timelock
		 * @since       1.0.0
		 */
		private static $instance;


		/**
		 * Get active instance
		 *
		 * @access      public
		 * @since       1.0.0
		 * @return      object self::$instance The one true RCP_Timelock
		 */
		public static function instance() {
			if( ! self::$instance ) {
				self::$instance = new RCP_Timelock();
				self::$instance->setup_constants();
				self::$instance->includes();
				self::$instance->hooks();
				self::$instance->load_textdomain();
			}

			return self::$instance;
		}


		/**
		 * Setup plugin constants
		 *
		 * @access      private
		 * @since       1.0.0
		 * @return      void
		 */
		public function setup_constants() {
			// Plugin version
			define( 'RCP_TIMELOCK_VER', '1.0.1' );

			// Plugin path
			define( 'RCP_TIMELOCK_DIR', plugin_dir_path( __FILE__ ) );

			// Plugin URL
			define( 'RCP_TIMELOCK_URL', plugin_dir_url( __FILE__ ) );
		}


		/**
		 * Include necessary files
		 *
		 * @access      private
		 * @since       1.0.0
		 * @return      void
		 */
		private function includes() {
			require_once RCP_TIMELOCK_DIR . 'includes/scripts.php';
			require_once RCP_TIMELOCK_DIR . 'includes/filters.php';
			require_once RCP_TIMELOCK_DIR . 'includes/cron-functions.php';

			if( is_admin() ) {
				require_once RCP_TIMELOCK_DIR . 'includes/admin/metabox.php';
			}
		}


		/**
		 * Run action and filter hooks
		 *
		 * @access      private
		 * @since       1.0.0
		 * @return      void
		 */
		private function hooks() {

			if( class_exists( 'RCP_Add_On_Updater' ) ) {
				$updater = new RCP_Add_On_Updater( 54992, __FILE__, RCP_TIMELOCK_VER );
			}

		}


		/**
		 * Internationalization
		 *
		 * @access      public
		 * @since       1.0.0
		 * @return      void
		 */
		public static function load_textdomain() {
			// Set filter for language directory
			$lang_dir = dirname( plugin_basename( __FILE__ ) ) . '/languages/';
			$lang_dir = apply_filters( 'rcp_timelock_languages_directory', $lang_dir );

			// Traditional WordPress plugin locale filter
			$locale = apply_filters( 'plugin_locale', get_locale(), 'rcp-timelock' );
			$mofile = sprintf( '%1$s-%2$s.mo', 'rcp-timelock', $locale );

			// Setup paths to current locale file
			$mofile_local  = $lang_dir . $mofile;
			$mofile_global = WP_LANG_DIR . '/rcp-timelock/' . $mofile;

			if( file_exists( $mofile_global ) ) {
				// Look in global /wp-content/languages/rcp-timelock/ folder
				load_textdomain( 'rcp-timelock', $mofile_global );
			} elseif( file_exists( $mofile_local ) ) {
				// Look in local /wp-content/plugins/rcp-timelock/languages/ folder
				load_textdomain( 'rcp-timelock', $mofile_local );
			} else {
				// Load the default language files
				load_plugin_textdomain( 'rcp-timelock', false, $lang_dir );
			}
		}
	}
}


/**
 * The main function responsible for returning the one true RCP_Timelock
 * instance to functions everywhere
 *
 * @since       1.0.0
 * @return      RCP_Timelock The one true RCP_Timelock
 */
function rcp_timelock() {
	return RCP_Timelock::instance();
}
add_action( 'plugins_loaded', 'rcp_timelock' );
